<?php
/**
 * Home Page Settings
 *
 * @package Excel_Business
 */

function excel_business_customize_register_home( $wp_customize ){	
    
    /** Front Page Settings*/
    $wp_customize->add_panel( 
        'home_page_setting', 
        array(
            'title'      => __( 'Front Page Settings', 'excel-business' ),
            'priority'   => 40,
            'capability' => 'edit_theme_options',
        ) 
    );
    
    /** Banner Slider */
    $wp_customize->add_section( 
        'banner_slider_setting', 
        array(
            'title'    => __( 'Banner Slider Section', 'excel-business' ),
            'priority' => 10,
            'panel'    => 'home_page_setting',
        ) 
    );
    
    /** Enable/Disable Banner Slider */
    $wp_customize->add_setting(
        'ed_slider',
        array(
            'default'           => true,
            'sanitize_callback' => 'excel_business_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
        'ed_slider',
        array(
            'label'       => __( 'Enable Banner Slider', 'excel-business' ),
            'description' => __( 'Enable to show Banner Slider on front page.', 'excel-business' ),
            'section'     => 'banner_slider_setting',
            'type'        => 'checkbox',            
        )
    );
    
    /** Enable/Disable Slider Auto Transition */
    $wp_customize->add_setting(
        'slider_auto',
        array(
            'default'           => true,
            'sanitize_callback' => 'excel_business_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
        'slider_auto',
        array(
            'label'   => __( 'Enable Slider Auto Transition', 'excel-business' ),
            'description' => __( 'Enable to automatically slide posts.', 'excel-business' ),
            'section' => 'banner_slider_setting',
            'type'    => 'checkbox',
        )
    );
    
    /** Enable/Disable Slider Loop */
    $wp_customize->add_setting(
        'slider_loop',
        array(
            'default'           => true,
            'sanitize_callback' => 'excel_business_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
        'slider_loop',
        array(
            'label'   => __( 'Enable Slider Loop', 'excel-business' ),
            'description' => __( 'Enable to continiously circle around slider post.', 'excel-business' ),
            'section' => 'banner_slider_setting',
            'type'    => 'checkbox',
        )
    );
    
    /** Enable/Disable Slider Control */
    $wp_customize->add_setting(
        'slider_control',
        array(
            'default'           => true,
            'sanitize_callback' => 'excel_business_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
        'slider_control',
        array(
            'label'   => __( 'Enable Slider Control', 'excel-business' ),
            'description' => __( 'Enable to show Prev/Next buttons.', 'excel-business' ),
            'section' => 'banner_slider_setting',
            'type'    => 'checkbox',
        )
    );
    
    /** Enable/Disable Slider Pager */
    $wp_customize->add_setting(
        'slider_pager',
        array(
            'default'           => true,
            'sanitize_callback' => 'excel_business_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
        'slider_pager',
        array(
            'label'   => __( 'Enable Slider Pager', 'excel-business' ),
            'description' => __( 'Enable to show pager button.', 'excel-business' ),
            'section' => 'banner_slider_setting',
            'type'    => 'checkbox',
        )
    );
    
    /** Enable/Disable Slider Caption */
    $wp_customize->add_setting(
        'slider_caption',
        array(
            'default'           => true,
            'sanitize_callback' => 'excel_business_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
        'slider_caption',
        array(
            'label'   => __( 'Enable Slider Caption', 'excel-business' ),
            'description' => __( 'Enable to show slider content.', 'excel-business' ),
            'section' => 'banner_slider_setting',
            'type'    => 'checkbox',
        )
    );
    
    /** Slider Animation */
    $wp_customize->add_setting(
        'slider_animation',
        array(
            'default'           => '',
            'sanitize_callback' => 'excel_business_sanitize_slider',
        )
    );
    
    $wp_customize->add_control(
        'slider_animation',
        array(
            'label'   => __( 'Choose Slider Animation', 'excel-business' ),
            'section' => 'banner_slider_setting',
            'type'    => 'select',
            'choices' => array(
                'fadeOut'        => __( 'Fade Out', 'excel-business' ),
                'fadeOutLeft'    => __( 'Fade Out Left', 'excel-business' ),
                'fadeOutRight'   => __( 'Fade Out Right', 'excel-business' ),
                'fadeOutUp'      => __( 'Fade Out Up', 'excel-business' ),
                'fadeOutDown'    => __( 'Fade Out Down', 'excel-business' ),
                ''               => __( 'Slide', 'excel-business' ),
                'slideOutLeft'   => __( 'Slide Out Left', 'excel-business' ),
                'slideOutRight'  => __( 'Slide Out Right', 'excel-business' ),
                'slideOutUp'     => __( 'Slide Out Up', 'excel-business' ),
                'slideOutDown'   => __( 'Slide Out Down', 'excel-business' ),
            )
        )
    );
    
    /** Select Category */
    $wp_customize->add_setting(
        'slider_cat',
        array(
            'default'           => '',
            'sanitize_callback' => 'excel_business_sanitize_select',
        )
    );
    
    $wp_customize->add_control(
        'slider_cat',
        array(
            'label'       => __( 'Select Category', 'excel-business' ),
            'description' => __( 'Select category to display banner slider.', 'excel-business' ),
            'section'     => 'banner_slider_setting',
            'type'        => 'select',
            'choices'     => excel_business_get_categories()
        )
    );
    
    
    /** Slider Read More */
    $wp_customize->add_setting(
        'slider_read_more',
        array(
            'default'           => __( 'Read More', 'excel-business' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'slider_read_more',
        array(
            'label'   => __( 'Slider Read More', 'excel-business' ),
            'section' => 'banner_slider_setting',
            'type'    => 'text'
        )
    );
    /** Banner Slider Ends */
    
    /** Intro Section */
    $wp_customize->add_section( 
        'intro_section', 
        array(
            'title'    => __( 'Intro Section', 'excel-business' ),
            'priority' => 15,
            'panel'    => 'home_page_setting',
        ) 
    );
    
    /** Enable/Disable Intro Section */
    $wp_customize->add_setting(
        'ed_intro',
        array(
            'default'           => true,
            'sanitize_callback' => 'excel_business_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
        'ed_intro',
        array(
            'label'       => __( 'Enable Intro Section', 'excel-business' ),
            'description' => __( 'Enable to show intro section on front page.', 'excel-business' ),
            'section'     => 'intro_section',
            'type'        => 'checkbox',            
        )
    );
    
    /** Intro Title */
    $wp_customize->add_setting(
        'intro_title',
        array(
            'default'           => __( 'Welcome to Excel Business', 'excel-business' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'intro_title',
        array(
            'label'   => __( 'Intro Title', 'excel-business' ),
            'section' => 'intro_section',
            'type'    => 'text'
        )
    );
    
    /** Intro Sub-Title */
    $wp_customize->add_setting(
        'intro_subtitle',
        array(
            'default'           => __( 'Show your introduction here. You can customize this section from Appearance > Customize > Front Page Settings > Intro Section.', 'excel-business' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'intro_subtitle',
        array(
            'label'   => __( 'Intro Sub Title', 'excel-business' ),
            'section' => 'intro_section',
            'type'    => 'text'
        )
    );
    /** Intro Section Ends */
    
    /** Portfolio Section */
    $wp_customize->add_section( 
        'portfolio_section', 
        array(
            'title'    => __( 'Portfolio Section', 'excel-business' ),
            'priority' => 25,
            'panel'    => 'home_page_setting',
        ) 
    );
    
    /** Enable/Disable Portfolio Section */
    $wp_customize->add_setting(
        'ed_portfolio',
        array(
            'default'           => true,
            'sanitize_callback' => 'excel_business_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
        'ed_portfolio',
        array(
            'label'       => __( 'Enable Portfolio Section', 'excel-business' ),
            'description' => __( 'Enable to show portfolio section on front page.', 'excel-business' ),
            'section'     => 'portfolio_section',
            'type'        => 'checkbox',            
        )
    );
    
    /** Portfolio Title */
    $wp_customize->add_setting(
        'portfolio_title',
        array(
            'default'           => __( 'Our Projects', 'excel-business' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'portfolio_title',
        array(
            'label'   => __( 'Portfolio Title', 'excel-business' ),
            'section' => 'portfolio_section',
            'type'    => 'text'
        )
    );
    
    /** Portfolio Sub-Title */
    $wp_customize->add_setting(
        'portfolio_subtitle',
        array(
            'default'           => __( 'Show your work, experiences and accomplishments here. You can customize this section from Appearance > Customize > Front Page Settings > Portfolio Section.', 'excel-business' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'portfolio_subtitle',
        array(
            'label'   => __( 'Portfolio Sub Title', 'excel-business' ),
            'section' => 'portfolio_section',
            'type'    => 'text'
        )
    );
    
    if( excel_business_is_ea_active() ){
        /** No. of Portfolio */
        $wp_customize->add_setting(
    		'no_of_portfolio',
    		array(
    			'default'			=> '6',
    			'sanitize_callback' => 'excel_business_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control( 
    		'no_of_portfolio',
    		array(
                'label'       => __( 'No. of Portfolio', 'excel-business' ),
                'description' => __( 'Choose number of Portfolio to display.', 'excel-business' ),
                'section'     => 'portfolio_section',            
    			'choices'     => array(
                    '3' => __( '3', 'excel-business' ),
                    '6' => __( '6', 'excel-business' ),
                ),
                'type'    => 'select'
     		)    		
    	);
        
        /** Portfolio Sub-Title */
        $wp_customize->add_setting(
            'portfolio_readmore',
            array(
                'default'           => __( 'View all', 'excel-business' ),
                'sanitize_callback' => 'sanitize_text_field',
            )
        );
        
        $wp_customize->add_control(
            'portfolio_readmore',
            array(
                'label'   => __( 'Readmore Text', 'excel-business' ),
                'section' => 'portfolio_section',
                'type'    => 'text'
            )
        );        
    }else{
        $wp_customize->add_setting(
    		'portfolio_note',
    		array(
    			'sanitize_callback' => 'wp_kses_post'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Excel_Business_Theme_Info( 
    			$wp_customize,
    			'portfolio_note',
    			array(
    				'section' => 'portfolio_section', 
                    //'label'       => __( 'Logo Category', 'excel-business' ),   				
                    'description' => sprintf( __( 'Please install and activate the recommended plugin %1$sExceltheme Addon%2$s. After that option related with this section will be visible.', 'excel-business' ), '<a href="' . admin_url( 'themes.php?page=tgmpa-install-plugins' ) . '" target="_blank">', '</a>' ),
    			)
    		)
       );        
    }
    /** Portfolio Section Ends */
    
    /** Testimonial Section */
    $wp_customize->add_section( 
        'testimonial_section', 
        array(
            'title'    => __( 'Testimonial Section', 'excel-business' ),
            'priority' => 30,
            'panel'    => 'home_page_setting',
        ) 
    );
    
    /** Enable/Disable Testimonial Section */
    $wp_customize->add_setting(
        'ed_testimonial',
        array(
            'default'           => true,
            'sanitize_callback' => 'excel_business_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
        'ed_testimonial',
        array(
            'label'       => __( 'Enable Testimonial Section', 'excel-business' ),
            'description' => __( 'Enable to show testimonial section on front page.', 'excel-business' ),
            'section'     => 'testimonial_section',
            'type'        => 'checkbox',            
        )
    );
    
    /** Testimonial Title */
    $wp_customize->add_setting(
        'testimonial_title',
        array(
            'default'           => __( 'What our clients says', 'excel-business' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'testimonial_title',
        array(
            'label'   => __( 'Testimonial Title', 'excel-business' ),
            'section' => 'testimonial_section',
            'type'    => 'text'
        )
    );
    
    /** Testimonial Sub-Title */
    $wp_customize->add_setting(
        'testimonial_subtitle',
        array(
            'default'           => __( 'Let your visitor know the real testimonial from here. You can customize this section from Appearance > Customize > Front Page Settings > Testimonial Section.', 'excel-business' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'testimonial_subtitle',
        array(
            'label'   => __( 'Testimonial Sub Title', 'excel-business' ),
            'section' => 'testimonial_section',
            'type'    => 'text'
        )
    );
    
    /** Background */
    $wp_customize->add_setting(
        'testimonial_bg',
        array(
            'default'           => get_template_directory_uri() . '/images/img8.jpg',
            'sanitize_callback' => 'esc_url_raw',
        )
    );
    
    $wp_customize->add_control(
        new WP_Customize_Image_Control(
            $wp_customize,
            'testimonial_bg',
            array(
                'label'   => __( 'Background', 'excel-business' ),
                'section' => 'testimonial_section', 
            )
        )
    );
    
    if( ! excel_business_is_ea_active() ){
        /** Testimonial Note */
        $wp_customize->add_setting(
    		'testimonial_note',
    		array(
    			'sanitize_callback' => 'wp_kses_post'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Excel_Business_Theme_Info( 
    			$wp_customize,
    			'testimonial_note',
    			array(
    				'section' => 'testimonial_section', 
                    //'label'       => __( 'Logo Category', 'excel-business' ),   				
                    'description' => sprintf( __( 'Please install and activate the recommended plugin %1$sExceltheme Addon%2$s. After that add testimonials which will be visible in this section.', 'excel-business' ), '<a href="' . admin_url( 'themes.php?page=tgmpa-install-plugins' ) . '" target="_blank">', '</a>' ),
    			)
    		)
        );
    }
    /** Testimonial Section Ends */
    
    /** Team Section */
    $wp_customize->add_section( 
        'team_section', 
        array(
            'title'    => __( 'Team Section', 'excel-business' ),
            'priority' => 35,
            'panel'    => 'home_page_setting',
        ) 
    );
    
    /** Enable/Disable Team Section */
    $wp_customize->add_setting(
        'ed_team',
        array(
            'default'           => true,
            'sanitize_callback' => 'excel_business_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
        'ed_team',
        array(
            'label'       => __( 'Enable Team Section', 'excel-business' ),
            'description' => __( 'Enable to show team section on front page.', 'excel-business' ),
            'section'     => 'team_section',
            'type'        => 'checkbox',            
        )
    );
    
    /** Team Title */
    $wp_customize->add_setting(
        'team_title',
        array(
            'default'           => __( 'Meet The Team', 'excel-business' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'team_title',
        array(
            'label'   => __( 'Team Title', 'excel-business' ),
            'section' => 'team_section',
            'type'    => 'text'
        )
    );
    
    /** Team Sub-Title */
    $wp_customize->add_setting(
        'team_subtitle',
        array(
            'default'           => __( 'Show your team member from here. You can customize this section from Appearance > Customize > Front Page Settings > Team Section.', 'excel-business' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'team_subtitle',
        array(
            'label'   => __( 'Team Sub Title', 'excel-business' ),
            'section' => 'team_section',
            'type'    => 'text'
        )
    );
    
    if( excel_business_is_ea_active() ){
        /** Team Post One */
        $wp_customize->add_setting(
    		'team_one',
    		array(
    			'default'			=> '',
    			'sanitize_callback' => 'excel_business_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control( 
    		'team_one',
    		array(
                'label'       => __( 'Team Post One', 'excel-business' ),
                'description' => __( 'Choose first team custom post.', 'excel-business' ),
                'section'     => 'team_section',            
    			'choices'     => excel_business_get_posts( 'ea_team' ),
                'type'        => 'select'
     		)    		
    	); 
        
        /** Team Post Two */
        $wp_customize->add_setting(
    		'team_two',
    		array(
    			'default'			=> '',
    			'sanitize_callback' => 'excel_business_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control( 
    		'team_two',
    		array(
                'label'       => __( 'Team Post Two', 'excel-business' ),
                'description' => __( 'Choose second team custom post.', 'excel-business' ),
                'section'     => 'team_section',            
    			'choices'     => excel_business_get_posts( 'ea_team' ),
                'type'        => 'select'
     		)    		
    	); 
        
        /** Team Post Three */
        $wp_customize->add_setting(
    		'team_three',
    		array(
    			'default'			=> '',
    			'sanitize_callback' => 'excel_business_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control( 
    		'team_three',
    		array(
                'label'       => __( 'Team Post Three', 'excel-business' ),
                'description' => __( 'Choose third team custom post.', 'excel-business' ),
                'section'     => 'team_section',            
    			'choices'     => excel_business_get_posts( 'ea_team' ),
                'type'        => 'select'
     		)    		
    	); 
        
        /** Team Post Four */
        $wp_customize->add_setting(
    		'team_four',
    		array(
    			'default'			=> '',
    			'sanitize_callback' => 'excel_business_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control( 
    		'team_four',
    		array(
                'label'       => __( 'Team Post Four', 'excel-business' ),
                'description' => __( 'Choose fourth team custom post.', 'excel-business' ),
                'section'     => 'team_section',            
    			'choices'     => excel_business_get_posts( 'ea_team' ),
                'type'        => 'select'
     		)    		
    	);        
    }else{
        $wp_customize->add_setting(
    		'team_note',
    		array(
    			'sanitize_callback' => 'wp_kses_post'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Excel_Business_Theme_Info( 
    			$wp_customize,
    			'team_note',
    			array(
    				'section' => 'team_section', 
                    'description' => sprintf( __( 'Please install and activate the recommended plugin %1$sExceltheme Addon%2$s. After that option related with this section will be visible.', 'excel-business' ), '<a href="' . admin_url( 'themes.php?page=tgmpa-install-plugins' ) . '" target="_blank">', '</a>' ),
    			)
    		)
       );        
    }
    /** Team Section Ends */
    
    /** Blog Section */
    $wp_customize->add_section( 
        'blog_setting', 
        array(
            'title'    => __( 'Blog Section', 'excel-business' ),
            'priority' => 40,
            'panel'    => 'home_page_setting',
        ) 
    );
    
    /** Enable/Disable Blog Section */
    $wp_customize->add_setting(
        'ed_blog_section',
        array(
            'default'           => true,
            'sanitize_callback' => 'excel_business_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
        'ed_blog_section',
        array(
            'label'       => __( 'Enable Blog Section', 'excel-business' ),
            'description' => __( 'Enable to show Blog Section on front page.', 'excel-business' ),
            'section'     => 'blog_setting',
            'type'        => 'checkbox',            
        )
    );
    
    /** Section Title */
    $wp_customize->add_setting(
        'blog_section_title',
        array(
            'default'           => __( 'Latest from the blog', 'excel-business' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'blog_section_title',
        array(
            'label'   => __( 'Section Title', 'excel-business' ),
            'section' => 'blog_setting',
            'type'    => 'text',            
        )
    );
    
    /** Section Sub-Title */
    $wp_customize->add_setting(
        'blog_section_content',
        array(
            'default'           => __( 'This is a short description describing about blog section.', 'excel-business' ),
            'sanitize_callback' => 'wp_kses_post',
        )
    );
    
    $wp_customize->add_control(
        'blog_section_content',
        array(
            'label'   => __( 'Section Sub-Title', 'excel-business' ),
            'section' => 'blog_setting',
            'type'    => 'text',            
        )
    );
    
    /** Read More */
    $wp_customize->add_setting(
        'readmore',
        array(
            'default'           => __( 'Read More...', 'excel-business' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'readmore',
        array(
            'label'   => __( 'Readmore Label', 'excel-business' ),
            'section' => 'blog_setting',
            'type'    => 'text',
        )
    );
    
    /** Button Label */
    $wp_customize->add_setting(
        'blog_section_button_label',
        array(
            'default'           => __( 'View all Posts', 'excel-business' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'blog_section_button_label',
        array(
            'label'       => __( 'View All Button Label', 'excel-business' ),
            'description' => __( 'This button will be visible only when Posts page is selected in Front page display settings.', 'excel-business' ),
            'section'     => 'blog_setting',
            'type'        => 'text',
        )
    );
    
    /** Contact Section */
    $wp_customize->add_section( 
        'contact_section', 
        array(
            'title'    => __( 'Contact Section', 'excel-business' ),
            'priority' => 45,
            'panel'    => 'home_page_setting',
        ) 
    );
    
    /** Enable/Disable Contact Section */
    $wp_customize->add_setting(
        'ed_contact',
        array(
            'default'           => true,
            'sanitize_callback' => 'excel_business_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
        'ed_contact',
        array(
            'label'       => __( 'Enable Contact Section', 'excel-business' ),
            'description' => __( 'Enable to show contact section on front page.', 'excel-business' ),
            'section'     => 'contact_section',
            'type'        => 'checkbox',            
        )
    );
    
    /** Contact Title */
    $wp_customize->add_setting(
        'contact_title',
        array(
            'default'           => __( 'Contact Us', 'excel-business' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'contact_title',
        array(
            'label'   => __( 'Contact Title', 'excel-business' ),
            'section' => 'contact_section',
            'type'    => 'text'
        )
    );
    
    /** Contact Sub-Title */
    $wp_customize->add_setting(
        'contact_subtitle',
        array(
            'default'           => __( 'Your visitor can reach you through contact form from here. You can customize this section from Appearance > Customize > Front Page Settings > Contact Section.', 'excel-business' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'contact_subtitle',
        array(
            'label'   => __( 'Contact Sub Title', 'excel-business' ),
            'section' => 'contact_section',
            'type'    => 'text'
        )
    );
    
    if( excel_business_is_cf7_activated() ){
        /** Contact Form */
        $wp_customize->add_setting(
    		'contact_form',
    		array(
    			'default'			=> '',
    			'sanitize_callback' => 'wp_kses_post'
    		)
    	);
    
    	$wp_customize->add_control( 
    		'contact_form',
    		array(
                'label'       => __( 'Contact Form', 'excel-business' ),
                'description' => __( 'Enter the Contact Form 7 Shortcode. Ex. [contact-form-7 id="137" title="Contact form 1"]', 'excel-business' ),
                'section'     => 'contact_section',
                'type'        => 'text'
     		)    		
    	);        
    }else{
        $wp_customize->add_setting(
    		'contact_note',
    		array(
    			'sanitize_callback' => 'wp_kses_post'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Excel_Business_Theme_Info( 
    			$wp_customize,
    			'contact_note',
    			array(
    				'section' => 'contact_section', 
                    'description' => sprintf( __( 'Please install and activate the recommended plugin %1$sContact Form 7%2$s. After that option related with this section will be visible.', 'excel-business' ), '<a href="' . admin_url( 'themes.php?page=tgmpa-install-plugins' ) . '" target="_blank">', '</a>' ),
    			)
    		)
       );        
    }
    /** Contact Section Ends */
}
add_action( 'customize_register', 'excel_business_customize_register_home' );